package org.appfuse.dao;

import java.util.List;

import org.appfuse.model.User;
import org.springframework.dao.DataAccessException;

public class UserDAOTest extends BaseDAOTestCase {
    private User user = null;
    private UserDAO dao = null;

    protected void setUp() throws Exception {
        super.setUp();
        dao = (UserDAO) ctx.getBean("userDAO");
    }

    protected void tearDown() throws Exception {
        dao = null;
    }

    public void testGetUsers() {
        // add a record to the database so we have something to work with
        user = new User();
        user.setFirstName("Rod");
        user.setLastName("Johnson");
        dao.saveUser(user);
        
        List users = dao.getUsers();
        assertTrue(users.size() >= 1);
        assertTrue(users.contains(user));
    }
    
    public void testSaveUser() throws Exception {
        user = new User();
        user.setFirstName("Rod");
        user.setLastName("Johnson");

        dao.saveUser(user);
        assertNotNull("primary key assigned", user.getId());
        log.info(user);
        assertNotNull(user.getFirstName());
    }

    public void testAddAndRemoveUser() throws Exception {
        user = new User();
        user.setFirstName("Bill");
        user.setLastName("Joy");

        dao.saveUser(user);

        assertNotNull(user.getId());
        assertEquals(user.getFirstName(), "Bill");

        if (log.isDebugEnabled()) {
            log.debug("removing user...");
        }

        dao.removeUser(user.getId());

        try {
            user = dao.getUser(user.getId());
            fail("User found in database");
        } catch (DataAccessException dae) {
            if (log.isDebugEnabled()) {
                log.debug("Expected exception: " + dae.getMessage());
            }

            assertNotNull(dae);
        }
    }
}
